/*
 * openwms.org, the Open Warehouse Management System.
 *
 * This file is part of openwms.org.
 *
 * openwms.org is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * openwms.org is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software. If not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.openwms.tms.domain.order {

    import flash.utils.IDataInput;
    import flash.utils.IDataOutput;
    import org.granite.collections.IPersistentCollection;
    import org.granite.meta;
    import org.granite.util.Enum;
    import org.openwms.common.domain.Location;
    import org.openwms.common.domain.LocationGroup;
    import org.openwms.common.domain.TransportUnit;
    import org.openwms.common.domain.values.Problem;
    import org.openwms.core.domain.AbstractEntity;
    import org.openwms.core.domain.DomainObject;
    import org.openwms.tms.domain.values.PriorityLevel;
    import org.openwms.tms.domain.values.TransportOrderState;

    use namespace meta;

    [Bindable]
    public class TransportOrderBase extends AbstractEntity implements DomainObject {

        private var __initialized:Boolean = true;
        private var __detachedState:String = null;

        protected var _creationDate:Date;
        protected var _dateUpdated:Date;
        protected var _endDate:Date;
        protected var _id:Number;
        protected var _priority:PriorityLevel;
        protected var _problem:Problem;
        protected var _sourceLocation:Location;
        protected var _startDate:Date;
        protected var _state:TransportOrderState;
        protected var _targetLocation:Location;
        protected var _targetLocationGroup:LocationGroup;
        protected var _transportUnit:TransportUnit;
        protected var _version:Number;

        override meta function isInitialized(name:String = null):Boolean {
            if (!name)
                return __initialized;

            var property:* = this[name];
            return (
                (!(property is TransportOrder) || (property as TransportOrder).meta::isInitialized()) &&
                (!(property is IPersistentCollection) || (property as IPersistentCollection).isInitialized())
            );
        }

        public function get creationDate():Date {
            return _creationDate;
        }

        public function get dateUpdated():Date {
            return _dateUpdated;
        }

        public function get endDate():Date {
            return _endDate;
        }

        public function get id():Number {
            return _id;
        }

        public function set priority(value:PriorityLevel):void {
            _priority = value;
        }
        public function get priority():PriorityLevel {
            return _priority;
        }

        public function set problem(value:Problem):void {
            _problem = value;
        }
        public function get problem():Problem {
            return _problem;
        }

        public function set sourceLocation(value:Location):void {
            _sourceLocation = value;
        }
        public function get sourceLocation():Location {
            return _sourceLocation;
        }

        public function get startDate():Date {
            return _startDate;
        }

        public function set state(value:TransportOrderState):void {
            _state = value;
        }
        public function get state():TransportOrderState {
            return _state;
        }

        public function set targetLocation(value:Location):void {
            _targetLocation = value;
        }
        public function get targetLocation():Location {
            return _targetLocation;
        }

        public function set targetLocationGroup(value:LocationGroup):void {
            _targetLocationGroup = value;
        }
        public function get targetLocationGroup():LocationGroup {
            return _targetLocationGroup;
        }

        public function set transportUnit(value:TransportUnit):void {
            _transportUnit = value;
        }
        public function get transportUnit():TransportUnit {
            return _transportUnit;
        }

        public function set version(value:Number):void {
            _version = value;
        }
        public function get version():Number {
            return _version;
        }

        public function isNew():Boolean {
            return true;
        }

        override public function readExternal(input:IDataInput):void {
            __initialized = input.readObject() as Boolean;
            __detachedState = input.readObject() as String;
            if (meta::isInitialized()) {
                super.readExternal(input);
                _creationDate = input.readObject() as Date;
                _dateUpdated = input.readObject() as Date;
                _endDate = input.readObject() as Date;
                _id = function(o:*):Number { return (o is Number ? o as Number : Number.NaN) } (input.readObject());
                _priority = Enum.readEnum(input) as PriorityLevel;
                _problem = input.readObject() as Problem;
                _sourceLocation = input.readObject() as Location;
                _startDate = input.readObject() as Date;
                _state = Enum.readEnum(input) as TransportOrderState;
                _targetLocation = input.readObject() as Location;
                _targetLocationGroup = input.readObject() as LocationGroup;
                _transportUnit = input.readObject() as TransportUnit;
                _version = function(o:*):Number { return (o is Number ? o as Number : Number.NaN) } (input.readObject());
            }
            else {
                _id = function(o:*):Number { return (o is Number ? o as Number : Number.NaN) } (input.readObject());
            }
        }

        override public function writeExternal(output:IDataOutput):void {
            output.writeObject(__initialized);
            output.writeObject(__detachedState);
            if (meta::isInitialized()) {
                super.writeExternal(output);
                output.writeObject(_creationDate);
                output.writeObject(_dateUpdated);
                output.writeObject(_endDate);
                output.writeObject(_id);
                output.writeObject(_priority);
                output.writeObject(_problem);
                output.writeObject(_sourceLocation);
                output.writeObject(_startDate);
                output.writeObject(_state);
                output.writeObject(_targetLocation);
                output.writeObject(_targetLocationGroup);
                output.writeObject(_transportUnit);
                output.writeObject(_version);
            }
            else {
                output.writeObject(_id);
            }
        }
    }
}